@@ -28,7 +28,6 @@ class Folders:
             response_list = response.json()
             for folder in response_list:
                 sub_folder = Folder.from_json(folder)
-                sub_folder.parent = self.rootFolder.id
                 folders_list.append(sub_folder)
             return folders_list
         else:
@@ -62,6 +61,7 @@ class Folders:
         """Create a new (sub)folder
 
         The name of the new folder must be unique under the same parent.
+        Folder names are case insensitive.
 
         API Endpoint: POST /folders/{id}
 
@@ -89,12 +89,20 @@ class Folders:
         response = self.session.post(f"{self.api}/folders", headers=headers)
 
         if response.status_code == 200:
-            logger.info(f"Folder '{name}' already exists")
-            for folder in self.folders:
-                if folder.name == name:
-                    return folder
-            logger.error("Folder exists but was not found in the user's folder list")
-            return
+            logger.info(
+                f"Folder '{name}' already exists under the folder {parent.name} ({parent.id})"
+            )
+            # Foldernames with similar letter but different cases
+            # are not allowed in Fossology, compare with lower case
+            existing_folder = [
+                folder
+                for folder in self.folders
+                if folder.name.lower() == name.lower() and folder.parent == parent.id
+            ]
+            if existing_folder:
+                return existing_folder[0]
+            description = f"Folder '{name}' exists but was not found under the folder {parent.name} ({parent.id})"
+            raise FossologyApiError(description, response)
 
         elif response.status_code == 201:
             logger.info(f"Folder {name} has been created")
